slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSViewMat

Prints one of the internal DS matrices.

### Synopsis

    #include "slepcds.h"
    PetscErrorCode DSViewMat(DS ds,PetscViewer viewer,DSMatType m)

Collective on ds

### Input Parameters

| ds | - the direct solver context
| viewer | - visualization context
| m | - matrix to display

### Note

Works only for ascii viewers. Set the viewer in Matlab format if want to paste into Matlab.

### See Also

DSView()

### Level

developer

### Location

src/sys/classes/ds/interface/dspriv.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages